from datetime import datetime
from google.cloud import bigquery



MASTER_CARD_PREFIXS = [
        ['5', '1'],
        ['5', '2'], 
        ['5', '3'], 
        ['5', '4'], 
        ['5', '5']
      ]

VISA_PREFIXS = [
        ['4', '5', '3', '9'],
        ['4', '5', '5', '6'],
        ['4', '9', '1', '6'],
        ['4', '5', '3', '2'],
        ['4', '9', '2', '9'],
        ['4', '0', '2', '4', '0', '0', '7', '1'],
        ['4', '4', '8', '6'],
        ['4', '7', '1', '6'],
        ['4']]

VISA = 'visa'
MASTER_CARD = 'master card'

BLOOD_GROUP = ['A+', 'A-', 'B+', 'B-', "O+", "O-", "AB+", "AB-"]

MONTHS = list(range(1, 13))

YEARS = list(range(datetime.today().year, datetime.today().year + 14))

CARDS_LIST = [VISA, MASTER_CARD]


MARIADB = 'maria'
MYSQL = 'msql'
POSTGRES = 'psql'
SQL = 'sql'

MARIADB_EXCLUDED_DBS = ['information_schema', 'mysql', 'performance_schema']

PSQL_EXCLUDED_DBS = ["information_schema", "mysql", "performance_schema", "sys", "postgres", "azure_maintenance", "azure_sys"]


PII_TABLE_SQL_QUERY = ( "CREATE TABLE if not exists PII ("
                        "first_name VARCHAR(255),"
                        "last_name VARCHAR(255),"
                        "address VARCHAR(255),"
                        "email VARCHAR(255),"
                        "country VARCHAR(255),"
                        "dob VARCHAR(255),"
                        "credit_card VARCHAR(255),"
                        "card_type VARCHAR(255),"
                        "cvv INTEGER,"
                        "height REAL,"
                        "weight INTEGER,"
                        "blood_group VARCHAR(255),"
                        "expiry_date VARCHAR(255))")



INSERT_QUERY_MARIADB = """ insert into PII (
first_name, last_name, address, email, country, dob, credit_card, card_type, cvv, expiry_date, height, weight, blood_group) 
values (%s,%s,%s,%s,%s,%s,%s,%s,%s,%s,%s,%s,%s)           
"""


AZURE_DATABASES = ['maria', 'sql', 'mysql', 'psql']

GCP_DATABASES = ["sql", "mysql", "psql"]


BIG_QUERY_SCHEMA = [
        bigquery.SchemaField("first_name", "STRING"),
        bigquery.SchemaField("last_name", "STRING"),
        bigquery.SchemaField("email", "STRING"),
        bigquery.SchemaField("dob", "STRING"),
        bigquery.SchemaField("address", "STRING"),
        bigquery.SchemaField("country", "STRING"),
        bigquery.SchemaField("blood_group", "STRING"),
        bigquery.SchemaField("height", "FLOAT"),
        bigquery.SchemaField("weight", "INTEGER"),
        bigquery.SchemaField("credit_card", "STRING"),
        bigquery.SchemaField("card_type", "STRING"),
        bigquery.SchemaField("last_name", "STRING"),
        bigquery.SchemaField("expiry_date", "STRING"),
    ]


import pytds
from pydantic import BaseModel, Field
from json import load as json_load

try:
  from production_config import PRODUCTION
except:
  from .production_config import PRODUCTION

  
if PRODUCTION:
    from .constants import MARIADB_EXCLUDED_DBS, PII_TABLE_SQL_QUERY, INSERT_QUERY_MARIADB
    from .utils import is_json_path_valid
else:
    from constants import MARIADB_EXCLUDED_DBS, PII_TABLE_SQL_QUERY, INSERT_QUERY_MARIADB
    from utils import is_json_path_valid



def get_sql_connection(config: dict):
    """
    this function is responsible for creating
     connection between app and psql db
    """
    # try:
    cnxn = pytds.connect(**config)
    cnxn.autocommit = True
    return cnxn
    # except OperationalError as e:
    #     return f" message :  //{e}"



class SqlConfig(BaseModel):
    """
    Have some validation
    """
    user: str = Field(...)
    password: str = Field(...)
    db_name: str = Field(...)
    host: str = Field(...)


def get_sql_config_data_from_json(file_path: str):

    if is_json_path_valid(file_path):
        f = open(file_path)
        data = json_load(f)
        f.close()
        try:
            SqlConfig(**data)
        except Exception as e:
            return f"message: {e}"
        return data
        
    else:
        return "message: kindly enter the valid path of json"



def enter_pii_data_in_gcp_sql(file_path: str, pii_data: list):
    config_data = get_sql_config_data_from_json(file_path)
    if type(config_data) == dict:
        conn = get_sql_connection(**config_data)
        cursor = conn.cursor()
        if config_data['db_name'] in MARIADB_EXCLUDED_DBS:
            cursor.execute("Create Database test;")
            print('test database has been created...')
            cursor.execute("Use test;")
        try:
            cursor.execute(PII_TABLE_SQL_QUERY)
        except:
            pass

        try:
            cursor.executemany(INSERT_QUERY_MARIADB, pii_data)
            cursor.execute("SELECT * from PII;")
            print(cursor.fetchall())
            cursor.close()
            conn.close()
        except Exception as e:
            return f"message : {str(e)}"
        
        return True

    else:
        return config_data



try:
  from production_config import PRODUCTION
except:
  from .production_config import PRODUCTION
import argparse
from pprint import pprint

if PRODUCTION:
  from .pii_data_generator import PIIGenerator
  from .constants import AZURE_DATABASES, GCP_DATABASES
else:
  from pii_data_generator import PIIGenerator
  from constants import AZURE_DATABASES, GCP_DATABASES



def get_cli_pii_data(args):
  """
  This function will parse all the arguments
  """
  use_all = False
  print(args)
  if args.a == "yes" or args.a == 'y':
    use_all = True
  pii_gen = PIIGenerator(args.n, args.c, use_all)
  # try:
  if args.conn != None:
    print(args.conn)
    pii_gen.insert_data_in_mongo(args.conn)
    print("*************" * 5)
    print("Data Inserted successfully")
  if args.filepath != None:
    s = pii_gen.get_data_in_json_file(args.filepath)
    print(str(s), "status of data insert")

  if args.cl.lower() == 'yes' or args.cl.lower() == 'y':


    if args.cloud_name.lower() == 'azure':

      if args.db_type == None:
        return "message: kindly select the db type in azure available are ['maria', 'sql', 'mysql', 'psql']"

      elif args.db_type.lower() in AZURE_DATABASES:

        # Maria db
        if args.db_type.lower() == 'maria':
          if args.json_path  == None:
            return "message: kindly add the path of database config file json for azure maria database"
          else:
            print('maria database')
            suc = pii_gen.insert_pii_data_in_azure_maria_db(args.json_path)
            return suc
                    # Mysql db
        elif args.db_type.lower() == 'mysql':
          
          if args.json_path  == None:
            return "message: kindly add the path of database config file json for azure mysql database"
          else:
            print('mysql database')
            suc = pii_gen.insert_pii_data_in_azure_mysql_db(args.json_path)
            return suc
        # Azure Psql
        elif args.db_type.lower() == 'psql':
            
          if args.json_path  == None:
            return "message: kindly add the path of database config file json for azure psql database"
          else:
            print('psql database')
            suc = pii_gen.insert_pii_data_in_azure_psql_db(args.json_path)
            return suc
        else:
          return f"message: database {args.db_type} is not available in azure available are ['maria', 'sql', 'mysql', 'psql']"

      else:
        return f"message: database {args.db_type} is not available in azure available are ['maria', 'sql', 'mysql', 'psql']"


    else:
      return f"message: cloud {args.cloud_name} is not available, available are ['azure', 'gcp']"





  return pii_gen.get_data_in_dict()

def main():
  parser = argparse.ArgumentParser()
  parser.add_argument('--n',
                      type=int, 
                      default=10,
                      help="number of PII data rows")

  parser.add_argument('--c',
                      type=str, 
                      default='visa',
                      help="select the card type availabel cards (visa, master card)")

  parser.add_argument('--a',
                      type=str, 
                      default='no',
                      help="if you want to use all card types Use 'yes'/'y' ")
  
  parser.add_argument('--conn',
                      type=str, 
                      default=None,
                      help="if you want to insert this data in Mongo database kindly enter the correct connection string")
  
  parser.add_argument('--filepath',
                      type=str, 
                      default=None,
                      help="if you want data in json file than provide the path where you want it.")
  
  parser.add_argument('--cl',
                      type=str,
                      default='no',
                      help="If you want to insert data in cloud's database than enter yes/y ")
                      
  parser.add_argument('--cloud_name',
                      type=str,
                      default=None,
                      help="Enter the cloud name available clouds are [azure, gcp]")
                                          
  parser.add_argument('--db_type',
                      type=str,
                      default=None,
                      help="Enter the db_type name available clouds are Azure = ['maria', 'sql', 'mysql', 'psql'] GCP=[sql, mysql, psql]")

  parser.add_argument('--json_path',
                      type=str,
                      default=None,
                      help="enter the config file path that have the credentials of database (file format json is needed)")

  
  args, unknown = parser.parse_known_args()

  print("============"*5)
  pprint(get_cli_pii_data(args))


print(main())


from google.cloud import bigquery
from json import load as json_load
from google.oauth2 import service_account

try:
  from production_config import PRODUCTION
except:
  from .production_config import PRODUCTION

  
if PRODUCTION:
    from .constants import BIG_QUERY_SCHEMA
    from .utils import is_json_path_valid
else:
    from constants import BIG_QUERY_SCHEMA
    from utils import is_json_path_valid


def get_bigquery_client(gcp_config_json: str):

  if is_json_path_valid(gcp_config_json):
      f = open(gcp_config_json)
      data = json_load(f)
      f.close()
      try:
        credential = service_account.Credentials.from_service_account_info(data)
        client = bigquery.Client(project=data["project_id"], credentials=credential)
        return [client, data.get("project_id", None), data.get("bq_dataset_name", None), data.get("bq_table_name", None)]
      except Exception as e:
        return f"message : {e}"

def remove(string):
    return string.replace(" ", "")
      
# submit the pii  data in 
def get_table_id_bq(ls: list):
  print(ls)
  result = []
  if ls[0] == None:
    project_id = input("Kindly enter the project id of gcp: ")
    result.append(project_id)
  else:
    result.append(ls[0])

  if ls[1] == None:
    dataset = input("Kindly enter the name of dataset of Gcp Bigquery: ")
    result.append(dataset)
  else:
     result.append(ls[1])
  if ls[2] == None:
    table = input("Kindly enter the name of table of Gcp Bigquery: ")
    result.append(table)
  else:
    result.append(ls[2])

  return ".".join(result)


def enter_pii_data_in_gcp_bigquery(config_path: str, dataframe):
  data = get_bigquery_client(config_path)
  if type(data) == list:
    bq_client = data[0]
    table_id = get_table_id_bq(data[1:])
    print(table_id)
    try:
      job_config = bigquery.LoadJobConfig(schema=BIG_QUERY_SCHEMA)
      load_job = bq_client.load_table_from_dataframe(
                                  dataframe,
                                  table_id, 
                                  job_config=job_config)
      print(load_job)

      load_job.result()  # Waits for the job to complete.

      destination_table = bq_client.get_table(table_id)
      print("Loaded {} rows.".format(destination_table.num_rows))
      return True
    except Exception as e:
      return f"message: {e}"
  else:
    return data



import psycopg2
from psycopg2 import OperationalError
from pydantic import BaseModel, Field
from json import load as json_load

try:
  from production_config import PRODUCTION
except:
  from .production_config import PRODUCTION

  
if PRODUCTION:
    from .constants import MARIADB_EXCLUDED_DBS, PII_TABLE_SQL_QUERY, INSERT_QUERY_MARIADB
    from .utils import is_json_path_valid
else:
    from constants import MARIADB_EXCLUDED_DBS, PII_TABLE_SQL_QUERY, INSERT_QUERY_MARIADB
    from utils import is_json_path_valid


def create_psql_connection_string(user: str, db_name: str,
                                  host: str, password: str):
    """
    this function is responsible for creating the psql connection string
     username: str = username of server
     password: str = password of server
     host: str = name of server
     db_name: str = name of database that want to scan
    """
    connection_string = (f"host={host} "
                         f"user={user} dbname={db_name} "
                         f"password={password} sslmode=require")
    return connection_string


def get_psql_connection(connection_string: str):
    """
    this function is responsible for creating
     connection between app and psql db
    """
    # try:
    print(connection_string)
    connection = psycopg2.connect(connection_string)
    connection.autocommit = True
    return connection
    # except OperationalError as e:
    #     return f" message :  //{e}"



class PsqlConfig(BaseModel):
    """
    Have some validation
    """
    user: str = Field(...)
    password: str = Field(...)
    db_name: str = Field(...)
    host: str = Field(...)


def get_psql_config_data_from_json(file_path: str):

    if is_json_path_valid(file_path):
        f = open(file_path)
        data = json_load(f)
        f.close()
        try:
            PsqlConfig(**data)
        except Exception as e:
            return f"message: {e}"
        return data
        
    else:
        return "message: kindly enter the valid path of json"



def enter_pii_data_in_gcp_psql(file_path: str, pii_data: list):
    config_data = get_psql_config_data_from_json(file_path)
    if type(config_data) == dict:
        conn_str  = create_psql_connection_string(**config_data)
        conn = get_psql_connection(conn_str)
        cursor = conn.cursor()
        if config_data['db_name'] in MARIADB_EXCLUDED_DBS:
            cursor.execute("Create Database test;")
            print('test database has been created...')
            cursor.execute("Use test;")
        try:
            cursor.execute(PII_TABLE_SQL_QUERY)
        except:
            pass

        try:
            cursor.executemany(INSERT_QUERY_MARIADB, pii_data)
            cursor.execute("SELECT * from PII;")
            print(cursor.fetchall())
            cursor.close()
            conn.close()
        except Exception as e:
            return f"message : {str(e)}"
        
        return True

    else:
        return config_data



import os
import json
import pandas as pd
from faker import  Faker
from datetime import datetime
from mongoengine import connect
from json import loads as json_loads

try:
  from production_config import PRODUCTION
except:
  from .production_config import PRODUCTION


if PRODUCTION:
  from .mongo_docs import PIIDocument
  from .gcp_mysql import enter_pii_data_in_gcp_mysql
  from .card_generator import CreditCardGenerator
  from .utils import ( return_prefix_ls, 
                      return_random_blood,
                      return_random_cvv,
                      return_random_height_weight,
                      return_expiry_date )
  from .maria import enter_pii_data_in_maria
  from .mysql_config import enter_pii_data_in_mysql
  from .psql_config import enter_pii_data_in_psql
  from .gcp_psql import enter_pii_data_in_gcp_psql
  from .gcp_sql import enter_pii_data_in_gcp_sql  
  from .gcp_bigquery import enter_pii_data_in_gcp_bigquery


else:
  from .mongo_docs import PIIDocument
  from .card_generator import CreditCardGenerator
  from .gcp_mysql import enter_pii_data_in_gcp_mysql
  from gcp_psql import enter_pii_data_in_gcp_psql
  from maria import enter_pii_data_in_maria
  from mysql_config import enter_pii_data_in_mysql
  from psql_config import enter_pii_data_in_psql
  from gcp_sql import enter_pii_data_in_gcp_sql  
  from gcp_bigquery import enter_pii_data_in_gcp_bigquery

  from .utils import ( return_prefix_ls, 
                      return_random_blood,
                      return_random_cvv,
                      return_random_height_weight,
                      return_expiry_date )
  



class PIIGenerator(object):

  def __init__(self,
               how_many: int = 10,
               credit_card_type: str = 'visa',
               both_credit_type: bool = False
              ):
      super().__init__()
      self.how_many = how_many
      self.credit_card_type = credit_card_type
      self.faker = Faker()
      self.both_credit_type = both_credit_type


  def return_dummy_pii_data(self):
    
    """
    this function will return dummy pii data 
    fake_obj : Faker Object
    how_many : int = how many data rows you want
    """
    try:

      fake_obj = self.faker

      card_gen = CreditCardGenerator(16, self.how_many)

      data_dict = {
                "first_name": [],
                "last_name": [],
                "address": [],
                "email": [],
                "country": [],
                "dob": [],
                "credit_card": [],
                "card_type": [],
                "cvv": [],
                "expiry_date": [],
                "height": [],
                "weight": [],
                "blood_group": []
            }


      for i in range(0, self.how_many): 
        prefix_ls, card_type = return_prefix_ls(self.credit_card_type, self.both_credit_type)
        if type(prefix_ls) == str:
          return prefix_ls
        name = fake_obj.name().split()
        height, weight = return_random_height_weight()
        data_dict["first_name"].append(name[0])
        data_dict["last_name"].append(name[1])
        data_dict["address"].append(fake_obj.address())
        data_dict["email"].append(fake_obj.email())
        data_dict["country"].append(fake_obj.country())
        data_dict["dob"].append(fake_obj.date())
        data_dict["blood_group"].append(return_random_blood())
        data_dict["height"].append(height)
        data_dict["weight"].append(weight)
        data_dict["card_type"].append(card_type)
        data_dict["credit_card"].append(card_gen.return_card_number(prefix_ls))
        data_dict["cvv"].append(return_random_cvv())
        data_dict["expiry_date"].append(return_expiry_date())
      return data_dict

    except Exception as e:
      return {f"message: something went wrong // {e}"}


  # class method return pandas dataframe
  def get_data_in_df(self):
    """
    This function will return PII data in Pandas Dataframe
    """
    try:
      return pd.DataFrame(self.return_dummy_pii_data())

    except Exception as e:
      return {f"message: something went wrong // {e}"}


  # class method return dict
  def get_data_in_dict(self):
    """
    This function will return PII data in dict
    """
    try:
      return self.get_data_in_df().to_dict('records')

    except Exception as e:
      return {f"message: something went wrong // {e}"}


  # class method return json
  def get_data_in_json(self):
    """
    This function will return PII data in json
    """
    try:
      return json_loads(self.return_dummy_pii_data())

    except Exception as e:
      return {f"message: something went wrong // {e}"}

  def get_data_in_json_file(self, json_path):
    """
    This function will return PII data in json file
    json_path: where you want that file
    """
  
    try:
      data = self.get_data_in_dict()
      file_path = os.path.join(json_path, f'data_{str(datetime.today().time())}.json')
      with open(file_path, 'w', encoding='utf-8') as f:
        json.dump(data, f, ensure_ascii=False, indent=4)
        f.close()
      return f"data imported in json successfully // {file_path}"

    except Exception as e:
      return {f"message: something went wrong // {e}"}


  # class method data insert in mongo
  def insert_data_in_mongo(self, connection_str: str):
    """
    This function will insert data in any mongo database using connection string
    connection_str: str = Mongo
    """
    try:

      data = self.get_data_in_dict()
      con = connect(host=connection_str)

      print("++++++++++++++++++++++++++++++++++++++ Connection Has been"
       " Established +++++++++++++++++++++++++++++++++++++++++++++++++++++++")
      mongo_docs = []
      for p in data:
        mongo_docs.append(PIIDocument(**p))
      PIIDocument.objects.insert(mongo_docs)
      con.close()
      return "data has been successfully added"

    except Exception as e:
      return e


  def get_data_for_sql(self):
    """
    This function will return PII data in 
    """
    try:
      return self.get_data_in_df().values.tolist()

    except Exception as e:
      return {f"message: something went wrong // {e}"}

  
  def insert_pii_data_in_azure_maria_db(self, config_file_path: str):
    """
    This function will insert PII data in Azure Maria db
    """
    print(config_file_path)
    try:
      pii_data = self.get_data_for_sql()
      insert_data = enter_pii_data_in_maria(config_file_path, pii_data)
      if type(insert_data) == bool:
        return "message: Data has been inserted successfully"
      return insert_data
    except Exception as e:
      return {f"message: something went wrong // {e}"}


  def insert_pii_data_in_azure_mysql_db(self, config_file_path: str):
    """
    This function will insert PII data in Azure Mysql db
    """
    try:
      pii_data = self.get_data_for_sql()
      insert_data = enter_pii_data_in_mysql(config_file_path, pii_data)
      if type(insert_data) == bool:
        return "message: Data has been inserted successfully"
      return insert_data
    except Exception as e:
      return {f"message: something went wrong // {e}"}


  def insert_pii_data_in_azure_psql_db(self, config_file_path: str):
    """
    This function will insert PII data in Azure Mysql db
    """
    try:
      pii_data = self.get_data_for_sql()
      insert_data = enter_pii_data_in_psql(config_file_path, pii_data)

      if type(insert_data) == bool:
        return "message: Data has been inserted successfully"
      return insert_data
      
    except Exception as e:
      return {f"message: something went wrong // {e}"}


  def insert_pii_data_in_gcp_psql_db(self, config_file_path: str):
    """
    This function will insert PII data in Azure Mysql db
    """
    try:
      pii_data = self.get_data_for_sql()
      insert_data = enter_pii_data_in_gcp_psql(config_file_path, pii_data)

      if type(insert_data) == bool:
        return "message: Data has been inserted successfully"
      return insert_data
      
    except Exception as e:
      return {f"message: something went wrong // {e}"}


  def insert_pii_data_in_gcp_sql_db(self, config_file_path: str):
    """
    This function will insert PII data in Azure Mysql db
    """
    try:
      pii_data = self.get_data_for_sql()
      insert_data = enter_pii_data_in_gcp_sql(config_file_path, pii_data)

      if type(insert_data) == bool:
        return "message: Data has been inserted successfully"
      return insert_data
      
    except Exception as e:
      return {f"message: something went wrong // {e}"}


  def insert_pii_data_in_gcp_mysql_db(self, config_file_path: str):
    """
    This function will insert PII data in Azure Mysql db
    """
    try:
      pii_data = self.get_data_for_sql()
      insert_data = enter_pii_data_in_gcp_mysql(config_file_path, pii_data)

      if type(insert_data) == bool:
        return "message: Data has been inserted successfully"
      return insert_data
      
    except Exception as e:
      return {f"message: something went wrong // {e}"}

  def insert_pii_data_in_gcp_big_query(self, config_file_path: str):
    """
    This function will insert PII data in Azure Mysql db
    """
    try:
      pii_data = self.get_data_in_df()
      insert_data = enter_pii_data_in_gcp_bigquery(config_file_path, pii_data)
      if type(insert_data) == bool:
        return "message: Data has been inserted successfully"
      return insert_data
      
    except Exception as e:
      return {f"message: something went wrong // {e}"}



p = PIIGenerator(how_many=400, both_credit_type=True)
print(p.insert_pii_data_in_gcp_big_query("/Users/deepak9636/Downloads/pii-data-generator-master/config_example/gcp_bigquery.json"))


from random import Random
import decimal

try:
  from production_config import PRODUCTION
except:
  from .production_config import PRODUCTION


if PRODUCTION:
  from .constants import *
else:
  from constants import *




def get_random_generator():
  """
  give the seeded random generator
  """
  generator = Random()
  generator.seed() 
  return generator


def return_prefix_ls(card_type: str, both_credit_type):
  """
  This function will give the perticular card list
  """
  if both_credit_type:
    generator = get_random_generator()
    card_type = generator.choice(CARDS_LIST)

  if card_type == MASTER_CARD:
    return MASTER_CARD_PREFIXS, card_type

  elif card_type == VISA:
    return VISA_PREFIXS, card_type

  else:
    return "this card type is not available"



def return_random_blood():
  """
  This function will give the random blood type
  """
  generator = get_random_generator()
  return generator.choice(BLOOD_GROUP)


def return_random_cvv():
  """
  This function will give the cvv number
  """
  generator = get_random_generator()
  num1, num2, num3 = generator.sample(range(1, 9), 3)
  return int((str(num1) + str(num2) + str(num3)))


def float_range(start, stop, step):
  """
  this function will create generator for float
  """
  while start < stop:
    yield float(start)
    start += decimal.Decimal(step)


def return_random_height_weight():
  """

  This function will give the random height and weight

  """
  generator = get_random_generator()
  height = generator.sample(list(float_range(5, 7, 0.1)), 1)[0]

  weight = generator.sample(range(50, 100), 1)[0]

  return height, weight


def return_expiry_date():
  """
  This function will give the expiry card date
  """
  generator = get_random_generator()
  month = generator.choice(MONTHS)

  year = generator.choice(YEARS)

  month =  str(month) if len(str(month)) == 2 else '0'+str(month)

  return  month+'/'+ str(year)


def is_json_path_valid(json_path: str):
  splitted = json_path.split('.')
  if splitted[-1].lower() == 'json':
    return True
  return False
  


from mongoengine import (Document, 
                         StringField, 
                         DateTimeField, 
                         IntField, 
                         FloatField)

from datetime import datetime

from mongoengine.fields import EmailField



class PIIDocument(Document):
    """
    Mongo document for PII Information
    """
    first_name = StringField()
    last_name = StringField()
    address = StringField()
    country = StringField()
    dob = DateTimeField()
    credit_card = StringField()
    card_type = StringField()
    cvv = IntField()
    height = FloatField()
    weight = IntField()
    email = EmailField()
    blood_group = StringField()
    expiry_date = StringField()
    updated_at = DateTimeField(default=str(datetime.now()))
    created_at = DateTimeField(default=str(datetime.now()))



import mysql.connector
from pathlib import Path
from pydantic import BaseModel, Field
from json import load as json_load
try:
  from production_config import PRODUCTION
except:
  from .production_config import PRODUCTION

  
if PRODUCTION:
    from .constants import MARIADB_EXCLUDED_DBS, PII_TABLE_SQL_QUERY, INSERT_QUERY_MARIADB
    from .utils import is_json_path_valid
else:
    from constants import MARIADB_EXCLUDED_DBS, PII_TABLE_SQL_QUERY, INSERT_QUERY_MARIADB
    from utils import is_json_path_valid


abs_path = Path(__file__).parent.absolute()

def get_mysql_connection(user: str, host: str,
                        database: str, password: str):
    
    """
    this function return mysql connection
    user: str = user name of database admin
    db_server_name: str = server name of database on azure
    db_port: str = database port on azure
    db_name: str = name of database
    """
    # try:
    connection = mysql.connector.connect(
        user=user,
        password=password,
        database=database,
        host=host
    )
    return connection


# Pydentic model

class MysqlConfig(BaseModel):
    """
    Have some validation
    """
    user: str = Field(...)
    password: str = Field(...)
    database: str = Field(...)
    host: str = Field(...)


def get_mysql_config_data_from_json(file_path: str):

    if is_json_path_valid(file_path):
        f = open(file_path)
        data = json_load(f)
        f.close()
        try:
            MysqlConfig(**data)
        except Exception as e:
            return f"message: {e}"
        return data
        
    else:
        return "message: kindly enter the valid path of json"


def enter_pii_data_in_gcp_mysql(file_path: str, pii_data: list):
    config_data = get_mysql_config_data_from_json(file_path)
    if type(config_data) == dict:
        conn = get_mysql_connection(**config_data)
        conn.autocommit = True
        cursor = conn.cursor()
        if config_data['database'] in MARIADB_EXCLUDED_DBS:
            cursor.execute("Create Database test;")
            cursor.execute("Use test;")
        try:
            cursor.execute(PII_TABLE_SQL_QUERY)
        except:
            pass

        try:
            cursor.executemany(INSERT_QUERY_MARIADB, pii_data)
            cursor.execute("SELECT * from PII;")
            print(cursor.fetchall())
            cursor.close()
            conn.close()
        except Exception as e:
            return f"message : {str(e)}"
        
        return True

    else:
        return config_data


# Insert the data in 





# s = get_maria_connection("microsec@mariaserver","mariaserver.mariadb.database.azure.com", 3306, 'test', 'admin@123')
# s.autocommit = True
# cur = s.cursor()

# database = 'test'

# # cur.execute("Drop table PII;")
# cur.execute("Use test;")
# p = PIIGenerator(how_many=4, both_credit_type=True)
# d = p.get_data_for_sql()
# print(d)
# cur.execute(PII_TABLE_SQL_QUERY)

# # # try:
# cur.executemany(INSERT_QUERY_MARIADB, d)
# cur.execute('Select * from PII;')
# print(cur.fetchall())
# except:
#     conn.rollback()



